@@ -1,10 +1,12 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Author::CSSON;
 
-our $VERSION = '0.1102'; # VERSION
+# ABSTRACT: Dist::Zilla plugin list (deprecated)
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1103';
 
 use Moose;
 use MooseX::AttributeShortcuts;
@@ -16,6 +18,7 @@ with 'Dist::Zilla::Role::PluginBundle::Config::Slicer';
 use namespace::autoclean;
 use List::AllUtils 'none';
 use Config::INI;
+use Path::Tiny;
 
 has installer => (
     is => 'rw',
@@ -56,7 +59,13 @@ has has_travis => (
 
 
 sub _build_homepage {
-    my $distname = Config::INI::Reader->read_file('dist.ini')->{'_'}{'name'};
+    my $distname;
+    if(path('iller.ini')->exists) {
+        $distname = Config::INI::Reader->read_file('iller.ini')->{'_'}{'name'};
+    }
+    elsif(path('dist.ini')->exists) {
+        $distname = Config::INI::Reader->read_file('dist.ini')->{'_'}{'name'};
+    }
     return sprintf 'https://metacpan.org/release/' . $distname;
 }
 
@@ -79,6 +88,7 @@ sub configure {
                                 'META.json',
                                 'LICENSE',
                                 'README.md',
+                                'iller.ini',
                                 $self->build_file,
                             ] },
         ],
@@ -90,16 +100,18 @@ sub configure {
         ],
         ['ReversionOnRelease', { prompt => 1 } ],
         ['OurPkgVersion'],
+        ['PodnameFromClassname'],
         ['NextRelease', { format => '%v  %{yyyy-MM-dd HH:mm:ss VVV}d' } ],
         ['PreviousVersion::Changelog'],
 
         ['NextVersion::Semantic', { major => '',
                                     minor => "API Changes, New Features, Enhancements",
-                                    revision => "Revision, Bug Fixes, Documentation, Meta",
+                                    revision => "Requirements, Testing, Revision, Bug Fixes, Documentation, Meta",
                                     format => '%d.%02d%02d',
                                     numify_version => 0,
                                   }
         ],
+        ['Iller::CleanupDistIni'],
         (
             $self->is_task ?
             ['TaskWeaver']
@@ -111,6 +123,7 @@ sub configure {
                            'Changes',
                            'META.json',
                            'README.md',
+                           'README',
                            $self->build_file,
                        ] },
         ],
@@ -120,6 +133,7 @@ sub configure {
             :
             ['GithubMeta', { issues => 1, homepage => $self->homepage } ]
         ),
+        ['Readme'],
         ['ReadmeAnyFromPod', { filename => 'README.md',
                                type => 'markdown',
                                location => 'root',
@@ -129,19 +143,22 @@ sub configure {
         ['Prereqs::FromCPANfile'],
         [ $self->installer ],
         ['MetaJSON'],
+        ['MetaProvides::Class'],
+        ['MetaProvides::Package'],
         ['ContributorsFromGit'],
         (
-            $ENV{'ILLER_AUTHOR_TEST'} ?
+            $ENV{'ILLERAT'} || $ENV{'ILLER_AUTHOR_TEST'} ?
             (
             ['Test::Kwalitee::Extra'],
             ['Test::NoTabs'],
             ['Test::EOL'],
             ['Test::EOF'],
-            ['PodSyntaxTests'],
+            ['Test::Version'],
             )
             :
             ()
         ),
+        ['PodSyntaxTests'],
         ['MetaYAML'],
         ['License'],
         ['ExtraTests'],
@@ -171,8 +188,6 @@ sub configure {
 
 1;
 
-# ABSTRACT: Dist::Zilla like Csson
-
 __END__
 
 =pod
@@ -181,169 +196,23 @@ __END__
 
 =head1 NAME
 
-Dist::Zilla::PluginBundle::Author::CSSON - Dist::Zilla like Csson
+Dist::Zilla::PluginBundle::Author::CSSON - Dist::Zilla plugin list (deprecated)
 
 =head1 VERSION
 
-version 0.1102
+Version 0.1103, released 2016-02-18.
 
-=head1 SYNOPSIS
+=head1 STATUS
 
-    ; in dist.ini
-    [@Author::CSSON]
+Deprecated. See L<Dist::Iller::Config::Author::CSSON> instead.
 
-=head1 DESCRIPTION
+=head1 SOURCE
 
-It is about the same as a dist.ini with these plugins specified:
+Source repository is at L<https://github.com/CSSON/p5-Dist-Zilla-PluginBundle-Author-CSSON>.
 
-    [Git::GatherDir]
-    exclude_filename = Build.PL ; or equivalent
-    exclude_filename = META.json
-    exclude_filename = LICENSE
-    exclude_filename = README.md
+=head1 HOMEPAGE
 
-    [CopyFilesFromBuild]
-    copy = META.json
-    copy = LICENSE
-    copy = Build.PL ; or equivalent
-
-    [ReversionOnRelease]
-    prompt = 1
-
-    [OurPkgVersion]
-
-    [NextRelease]
-    format = %v  %{yyyy-MM-dd HH:mm:ss VVV}d
-
-    [PreviousVersion::Changelog]
-    [NextVersion::Semantic]
-    major =
-    minor = API Changes, New Features, Enhancements
-    revision = Revision, Bug Fixes, Documentation, Meta
-    format = %d.%02d%02d
-    numify_version = 0
-
-    [Git::Check]
-    allow_dirty = dist.ini
-    allow_dirty = Changes
-    allow_dirty = META.json
-    allow_dirty = README.md
-    allow_dirty = Build.PL ; or equivalent
-
-    ; if is_private == 0, see below
-    [GithubMeta]
-    issues = 1
-    homepage = http://metacpan.org/release/dist-name
-
-    [PodWeaver]
-    config_bundle = @Author::CSSON
-
-    [ReadmeAnyFromPod]
-    filename = README.md
-    type = markdown
-    location = root
-
-    [MetaNoIndex]
-    directory = t
-    directory = xt
-    directory = inc
-    directory = share
-    directory = eg
-    directory = examples
-
-    [Prereqs::FromCPANfile]
-
-    ; settable, see installer below
-    [ModuleBuildTiny]
-
-    [MetaJSON]
-
-    [ContributorsFromGit]
-
-    [Test::NoTabs]
-    [Test::EOL]
-    [Test::EOF]
-    [PodSyntaxTests]
-    [Test::Kwalitee::Extra]
-
-    [MetaYAML]
-
-    [License]
-
-    [ExtraTests]
-
-    [ShareDir]
-
-    [Manifest]
-
-    [ManifestSkip]
-
-    [CheckChangesHasContent]
-
-    [TestRelease]
-
-    [ConfirmRelease]
-
-    ; depends on is_private, see below
-    [UploadToCPAN or UploadToStratopan]
-
-    [Git::Commit]
-    commit_msg = %v
-    allow_dirty = dist.ini
-    allow_dirty = Changes
-    allow_dirty = META.json
-    allow_dirty = README.md
-    allow_dirty = Build.PL
-
-    [Git::Tag]
-    tag_format = %v
-    tag_message =
-
-    [Git::Push]
-    remotes_must_exist = 0
-
-=head1 OPTIONS
-
-=head2 homepage
-
-String. Default is the release's page on metacpan.org. Not set if C<is_private> is true.
-
-=head2 installer
-
-String. Default is L<ModuleBuildTiny|Dist::Zilla::ModuleBuildTiny>.
-
-=head2 is_private
-
-Boolean. Default is B<0>.
-
-If false: Adds github repository to meta, uses github as issue tracker, and includes L<UploadToCPAN|Dist::Zilla::Plugin::UploadToCPAN>.
-
-If true: Adds no github information, and includes L<UploadToStratopan|Dist::Zilla::Plugin::UploadToStratopan>.
-
-To remove L<UploadToStratopan|Dist::Zilla::Plugin::UploadToStratopan>, add this to your dist.ini:
-
-    -remove = UploadToStratopan
-
-To use L<UploadToStratopan|Dist::Zilla::Plugin::UploadToStratopan>, you need to specify C<repo> and C<stack> in dist.ini:
-
-    UploadToStratopan.repo = ...
-    UploadToStratopan.stack = ...
-
-=head2 is_task
-
-Boolean. Default is B<0>.
-
-If true, L<Dist::Zilla::Plugin::TaskWeaver> is included instead of L<Dist::Zilla::Plugin::PodWeaver>.
-
-=head2 weaver_config
-
-String. Default is L<@Author::CSSON|Pod::Weaver::PluginBundle::Author::CSSON>.
-
-=head1 SEE ALSO
-
-L<Dist::Zilla>
-
-L<Pod::Weaver::PluginBundle::Author::CSSON>
+L<https://metacpan.org/release/Dist-Zilla-PluginBundle-Author-CSSON>
 
 =head1 AUTHOR
 
@@ -351,7 +220,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2016 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
